@@ -106,8 +106,8 @@ class Latex2pdfa:
         """
         self.script_name = __file__  # the name of the script
         d = os.path.dirname(sys.modules[self.script_name].__file__)
-        self.resources = (d / 'resources').absolute()
-        self.binaries = (d / 'binaries').absolute()
+        self.resources = (Path(d) / 'resources').absolute()
+        self.binaries = (Path(d) / 'binaries').absolute()
 
         self.main_tex_file = Path(main_tex_file)
         assert conformance_level in ['a', 'b', 'u']
